<?php
/**
 * Implements a custom header for WPstart.
 *
 * @link http://codex.wordpress.org/Custom_Headers
 *
 * @package WPstart
 * @since WPstart 1.1.5
 */

/**
 * Sets up the WordPress core custom header arguments and settings.
 *
 * @uses wpstart_header_style()
 * @uses wpstart_admin_header_style()
 * @uses wpstart_admin_header_image()
 * @uses add_theme_support()
 * @uses register_default_headers()
 */
function wpstart_custom_header_setup() {
	$args = array(
		'default-image'          => '%s/images/headers/default.png',
		'random-default'         => false,
		'width'                  => 1140,
		'height'                 => 300,
		'flex-height'            => false,
		'flex-width'             => false,
		'default-text-color'     => '000000',
		'header-text'            => true,
		'uploads'                => true,		
		'wp-head-callback'       => 'wpstart_header_style',
		'admin-head-callback'    => 'wpstart_admin_header_style',
		'admin-preview-callback' => 'wpstart_admin_header_image',
	);

	// Adds support for a custom header image.
	add_theme_support( 'custom-header', $args );

	/*
	 * Register a default header to be displayed by the custom header admin UI.
	 * The %s is replaced with theme template directory URI.
	 * To reference a image in a child theme (ie in the stylesheet directory), use %2$s instead of %s.
	 */
	register_default_headers( array(
		'default' => array(
			'url'           => '%s/images/headers/default.png',
			'thumbnail_url' => '%s/images/headers/default-thumbnail.png',
			'description'   => __( 'Default', 'wpstart' )
		)
	) );
}
add_action( 'after_setup_theme', 'wpstart_custom_header_setup' );

/**
 * Styles the header displayed on front-end.
 */
function wpstart_header_style() {
	if ( HEADER_TEXTCOLOR == get_header_textcolor() )
		return; ?>
		<style type="text/css">
		<?php if ( 'blank' == get_header_textcolor() ) : ?>
			.site-title,
			.site-description { 
				display: none!important;
				visibility: hidden!important;
			}
		<?php else : ?>
			.site-title a,
			.site-description {
				color: #<?php echo get_header_textcolor(); ?>!important;
			}
		<?php endif; ?>
		</style>
<?php }

/**
 * Add custom styles to header image displayed on the Appearance > Header admin panel.
 */
function wpstart_admin_header_style() { ?>
	<style type="text/css">
	#header {
		background-color: #ffffff;
		clear: both;
		padding: 20px 0 0;
	}

	#header hgroup {
		min-height: 1px;
		padding-right: 15px;
		padding-left: 15px;
		position: relative;
	}
	
	h1.site-title {	
		color: #000000;
		font-size: 36px;
		font-weight: bold;
		line-height: 1;
		margin: 0;
	}

	h1.site-title a {
		color: #000000;
		font-family: "Helvetica Neue", Helvetica, Arial, sans-serif; 
		text-decoration: none;
	}

	h1.site-title a:hover {
		color: #000;
		text-decoration: none;
	}

	h2.site-description {
		font-family: "Helvetica Neue", Helvetica, Arial, sans-serif; 
		font-size: 12px;
		font-weight: bold;
		line-height: 1;
		margin: 0 0 10px;
		padding: 0;
	}

	/* Header image */
	.header-image {
		min-height: 1px;
		padding-right: 15px;
		padding-left: 15px;
		position: relative;
	}
	
	img.header-image {
		max-width: 100%;
		height: auto;
	}
	
	@media screen and (max-width: 767px) {
		/* Header */
		#header hgroup {
			text-align: center;
		}
	}

	@media screen and (min-width: 768px) {
		/* Header */
		#header hgroup {
			float: left;
			width: 25%;
		}
	}
	</style>
<?php }

/**
 * Add custom markup to header image displayed on the Appearance > Header admin panel.
 */
function wpstart_admin_header_image() { ?>
	<header id="header">
		<hgroup>
			<h1 class="site-title">
				<a href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>"><?php bloginfo( 'name' ); ?></a>
			</h1>
			<?php $site_description = get_bloginfo('description');
			if ( ! empty( $site_description ) ) : ?>		
			<h2 class="site-description"><?php bloginfo('description'); ?></h2>
			<?php endif; ?>
		</hgroup>		
	
		<?php $header_image = get_header_image();
		if ( ! empty( $header_image ) ) : ?>
			<img src="<?php echo esc_url( $header_image ); ?>" width="<?php echo HEADER_IMAGE_WIDTH; ?>" height="<?php echo HEADER_IMAGE_HEIGHT; ?>" alt="" class="header-image" />
		<?php endif; ?>
	</header>
<?php }
