<?php
/**
 * Adds boxed/wide layout option on posts and pages.
 *
 * @package WPstart
 * @since WPstart 1.1.5
 */
 
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
* Adds a box to the side column on the Page and Post edit screens.
*/
function wpstart_post_custom_meta_layout_style_add_meta_box() {
	$post_types = array( 'page', 'post' );
	
	foreach ( $post_types as $post_type ) {
		add_meta_box( 
			'wpstart_post_custom_meta_layout_style_meta_box', 
			__( 'Screen Layout', 'wpstart' ), 
			'wpstart_post_custom_meta_layout_style_layout_meta_box', 
			$post_type, 
			'side', 
			'default' 
		);
    }
}
add_action( 'add_meta_boxes', 'wpstart_post_custom_meta_layout_style_add_meta_box' );

/**
* wpstart_post_custom_meta_layout_style_layout_meta_box function.
*/
function wpstart_post_custom_meta_layout_style_layout_meta_box() {
	global $post;
	$custom        = ( get_post_custom( $post->ID ) ? get_post_custom( $post->ID ) : false );
	$layout        = ( isset( $custom['_wpstart_layout_style'][0] ) ? $custom['_wpstart_layout_style'][0] : 'default' );
	$valid_layouts = wpstart_post_custom_meta_layout_style_layout_get_valid_layouts();
	?>
	<p>
		<label><input type="radio" name="_wpstart_layout_style" <?php checked( 'default' == $layout ); ?> value="default" />
		<?php _e( 'Default', 'wpstart' ); ?></label><br/>
		<?php foreach( $valid_layouts as $slug => $name ) { ?>
			<label><input type="radio" name="_wpstart_layout_style" <?php checked( $slug == $layout ); ?> value="<?php echo $slug; ?>" />
			<?php echo $name; ?></label><br/>
		<?php } ?>
	</p>
<?php
}

/**
* wpstart_post_custom_meta_layout_style_layout_save_post_metadata function.
*/
function wpstart_post_custom_meta_layout_style_layout_save_post_metadata() {
	global $post;
	if( !isset( $post ) || !is_object( $post ) ) {
		return;
	}
	$valid_layouts = wpstart_post_custom_meta_layout_style_layout_get_valid_layouts();
	$layout        = ( isset( $_POST['_wpstart_layout_style'] ) && array_key_exists( $_POST['_wpstart_layout_style'], $valid_layouts ) ? $_POST['_wpstart_layout_style'] : 'default' );

	update_post_meta( $post->ID, '_wpstart_layout_style', $layout );
}

// Hook the save layout post custom meta data into
// publish_{post-type}, draft_{post-type}, and future_{post-type}
add_action( 'publish_post', 'wpstart_post_custom_meta_layout_style_layout_save_post_metadata' );
add_action( 'publish_page', 'wpstart_post_custom_meta_layout_style_layout_save_post_metadata' );
add_action( 'draft_post', 'wpstart_post_custom_meta_layout_style_layout_save_post_metadata' );
add_action( 'draft_page', 'wpstart_post_custom_meta_layout_style_layout_save_post_metadata' );
add_action( 'future_post', 'wpstart_post_custom_meta_layout_style_layout_save_post_metadata' );
add_action( 'future_page', 'wpstart_post_custom_meta_layout_style_layout_save_post_metadata' );


/**
 * Get valid layouts.
 */
function wpstart_post_custom_meta_layout_style_layout_get_valid_layouts() {
	$layouts = array(
		'boxed' => __( 'Boxed', 'wpstart' ),
		'wide' 	=> __( 'Wide', 'wpstart' )
	);

	return apply_filters( 'wpstart_post_custom_meta_layout_style_layout_valid_layouts', $layouts );
}

/**
 * Get current layout.
 */
function wpstart_post_custom_meta_layout_style_layout_get_layout() {
	/* 404 pages */
	if( is_404() ) {
		return 'default';
	}
	$layout = '';
	
	$valid_layouts = wpstart_post_custom_meta_layout_style_layout_get_valid_layouts();

	global $post;
	$layout_meta_value = ( false != get_post_meta( get_the_ID(), '_wpstart_layout_style', true ) ? get_post_meta( get_the_ID(), '_wpstart_layout_style', true ) : 'default' );
	$layout_meta       = ( array_key_exists( $layout_meta_value, $valid_layouts ) ? $layout_meta_value : 'default' );	
	
	if( 'default' != $layout_meta ) {
		$layout = $layout_meta;
	} else {
		$layout = 'default';	
	}

	return apply_filters( 'wpstart_post_custom_meta_layout_style_layout_get_layout', $layout );
}

/**
 * Get content classes.
 */
function wpstart_post_custom_meta_layout_style_layout_get_main_classes() {
	$content_classes = array();
	$layout          = wpstart_post_custom_meta_layout_style_layout_get_layout();
	
	if( in_array( $layout, array( 'default', 'boxed' ) ) ) {
		$content_classes[] = 'layout-boxed';
	}
	else {
		if( 'wide' == $layout ) {
			$content_classes[] = 'layout-wide';
		}
		else {
			if( 'boxed' == $layout ) {
				$content_classes[] = 'layout-boxed';
			}
		}
	}

	return apply_filters( 'wpstart_content_classes', $content_classes );
}

/**
 * wpstart_post_custom_meta_layout_style_layout_main_classes function.
 */
function wpstart_post_custom_meta_layout_style_layout_main_classes() {
	echo implode( ' ', wpstart_post_custom_meta_layout_style_layout_get_main_classes() );
}

/**
 * wpstart_main_start_cutom_layout function.
 */
function wpstart_main_start_cutom_layout() { 
	$wrapper_class =  implode( ' ', wpstart_post_custom_meta_layout_style_layout_get_main_classes() );
	
	$wrapper_start = "\t\t";
	$wrapper_start .= '<div id="wrapper" class="'. $wrapper_class .'">';
	$wrapper_start .= "\n";
	
	return $wrapper_start;	
}
add_filter( 'wpstart_wrapper_start', 'wpstart_main_start_cutom_layout' );
?>